Foobot async API Client
=======================

.. image:: https://img.shields.io/pypi/v/foobot_async.svg
    :target: https://pypi.python.org/pypi/foobot_async
    :alt: Latest PyPI version

.. image:: https://travis-ci.org/reefab/foobot_async.png
   :target: https://travis-ci.org/reefab/foobot_async
   :alt: Latest Travis CI build status

.. image:: https://coveralls.io/repos/github/reefab/foobot_async/badge.svg?branch=master
   :target: https://coveralls.io/github/reefab/foobot_async?branch=master

.. image:: https://readthedocs.org/projects/foobot-async/badge/?version=latest
   :target: http://foobot-async.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

API Client for `Foobot <https://foobot.io>`_ Air Quality Monitoring devices.

.. image:: https://cdn-foobot.pressidium.com/wp-content/uploads/2016/09/device2.jpg

Uses `aiohttp <https://aiohttp.readthedocs.io/en/stable/>`_.

Usage
-----

Once you have your device setup and working, you'll need to get an API key.

You can register for one at their `developers site <https://api.foobot.io/apidoc/index.html>`_.

Compatibility
-------------

 * Python 3.5
 * Python 3.6
